# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiError(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"message": "str", "name": "str", "request_id": "str"}

    attribute_map = {"message": "message", "name": "name", "request_id": "request_id"}

    def __init__(self, message=None, name=None, request_id=None):  # noqa: E501
        """ApiError - a model defined in Swagger"""  # noqa: E501

        self._message = None
        self._name = None
        self._request_id = None
        self.discriminator = None

        self.message = message
        self.name = name
        if request_id is not None:
            self.request_id = request_id

    @property
    def message(self):
        """Gets the message of this ApiError.  # noqa: E501

        A human-readable explanation specific to this occurrence of the problem.  # noqa: E501

        :return: The message of this ApiError.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ApiError.

        A human-readable explanation specific to this occurrence of the problem.  # noqa: E501

        :param message: The message of this ApiError.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError(
                "Invalid value for `message`, must not be `None`"
            )  # noqa: E501

        self._message = message

    @property
    def name(self):
        """Gets the name of this ApiError.  # noqa: E501

        A short, human-readable summary of the problem that *should not* change from occurrence to occurrence of the problem, except for purposes of localization.  # noqa: E501

        :return: The name of this ApiError.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApiError.

        A short, human-readable summary of the problem that *should not* change from occurrence to occurrence of the problem, except for purposes of localization.  # noqa: E501

        :param name: The name of this ApiError.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def request_id(self):
        """Gets the request_id of this ApiError.  # noqa: E501

        Request ID  # noqa: E501

        :return: The request_id of this ApiError.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this ApiError.

        Request ID  # noqa: E501

        :param request_id: The request_id of this ApiError.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ApiError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ChangedPlanData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "details": "str",
        "updated": "datetime",
        "is_executed": "bool",
        "name_to": "str",
        "name": "str",
        "status_to": "str",
        "status": "str",
    }

    attribute_map = {
        "id": "id",
        "details": "details",
        "updated": "updated",
        "is_executed": "is_executed",
        "name_to": "name_to",
        "name": "name",
        "status_to": "status_to",
        "status": "status",
    }

    def __init__(
        self,
        id=None,
        details=None,
        updated=None,
        is_executed=None,
        name_to=None,
        name=None,
        status_to=None,
        status=None,
    ):  # noqa: E501
        """ChangedPlanData - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._details = None
        self._updated = None
        self._is_executed = None
        self._name_to = None
        self._name = None
        self._status_to = None
        self._status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if details is not None:
            self.details = details
        if updated is not None:
            self.updated = updated
        if is_executed is not None:
            self.is_executed = is_executed
        if name_to is not None:
            self.name_to = name_to
        if name is not None:
            self.name = name
        if status_to is not None:
            self.status_to = status_to
        if status is not None:
            self.status = status

    @property
    def id(self):
        """Gets the id of this ChangedPlanData.  # noqa: E501

        Represents the ID of the modified plan  # noqa: E501

        :return: The id of this ChangedPlanData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChangedPlanData.

        Represents the ID of the modified plan  # noqa: E501

        :param id: The id of this ChangedPlanData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def details(self):
        """Gets the details of this ChangedPlanData.  # noqa: E501

        The reason why request was unsuccessful  # noqa: E501

        :return: The details of this ChangedPlanData.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this ChangedPlanData.

        The reason why request was unsuccessful  # noqa: E501

        :param details: The details of this ChangedPlanData.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def updated(self):
        """Gets the updated of this ChangedPlanData.  # noqa: E501

        Plan update date  # noqa: E501

        :return: The updated of this ChangedPlanData.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ChangedPlanData.

        Plan update date  # noqa: E501

        :param updated: The updated of this ChangedPlanData.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    @property
    def is_executed(self):
        """Gets the is_executed of this ChangedPlanData.  # noqa: E501

        Indicates was the request successful or not  # noqa: E501

        :return: The is_executed of this ChangedPlanData.  # noqa: E501
        :rtype: bool
        """
        return self._is_executed

    @is_executed.setter
    def is_executed(self, is_executed):
        """Sets the is_executed of this ChangedPlanData.

        Indicates was the request successful or not  # noqa: E501

        :param is_executed: The is_executed of this ChangedPlanData.  # noqa: E501
        :type: bool
        """

        self._is_executed = is_executed

    @property
    def name_to(self):
        """Gets the name_to of this ChangedPlanData.  # noqa: E501

        New plan name -  for RENAME operation only  # noqa: E501

        :return: The name_to of this ChangedPlanData.  # noqa: E501
        :rtype: str
        """
        return self._name_to

    @name_to.setter
    def name_to(self, name_to):
        """Sets the name_to of this ChangedPlanData.

        New plan name -  for RENAME operation only  # noqa: E501

        :param name_to: The name_to of this ChangedPlanData.  # noqa: E501
        :type: str
        """

        self._name_to = name_to

    @property
    def name(self):
        """Gets the name of this ChangedPlanData.  # noqa: E501

        Name of modified plan. Will be returned for `RENAME` operation  # noqa: E501

        :return: The name of this ChangedPlanData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChangedPlanData.

        Name of modified plan. Will be returned for `RENAME` operation  # noqa: E501

        :param name: The name of this ChangedPlanData.  # noqa: E501
        :type: str
        """

        self._name = name

    class StatusTo(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"

    @property
    def status_to(self):
        """Gets the status_to of this ChangedPlanData.  # noqa: E501

        New state of plan (active or hold) -  for CHANGE_STATUS operation only  # noqa: E501

        :return: The status_to of this ChangedPlanData.  # noqa: E501
        :rtype: str
        """
        return self._status_to

    @status_to.setter
    def status_to(self, status_to):
        """Sets the status_to of this ChangedPlanData.

        New state of plan (active or hold) -  for CHANGE_STATUS operation only  # noqa: E501

        :param status_to: The status_to of this ChangedPlanData.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]  # noqa: E501
        if status_to not in allowed_values:
            raise ValueError(
                "Invalid value for `status_to` ({0}), must be one of {1}".format(  # noqa: E501
                    status_to, allowed_values
                )
            )

        self._status_to = status_to

    class Status(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"

    @property
    def status(self):
        """Gets the status of this ChangedPlanData.  # noqa: E501

        Status of modified plan ('ACTIVE' or 'HOLD'). Will be returned for `CHANGE_STATUS` operation  # noqa: E501

        :return: The status of this ChangedPlanData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ChangedPlanData.

        Status of modified plan ('ACTIVE' or 'HOLD'). Will be returned for `CHANGE_STATUS` operation  # noqa: E501

        :param status: The status of this ChangedPlanData.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ChangedPlanData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangedPlanData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PayoutRequestPayoutData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "currency": "str",
        "dynamic_descriptor": "str",
        "note": "str",
    }

    attribute_map = {
        "amount": "amount",
        "currency": "currency",
        "dynamic_descriptor": "dynamic_descriptor",
        "note": "note",
    }

    def __init__(
        self, amount=None, currency=None, dynamic_descriptor=None, note=None
    ):  # noqa: E501
        """PayoutRequestPayoutData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self._dynamic_descriptor = None
        self._note = None
        self.discriminator = None

        self.amount = amount
        self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if note is not None:
            self.note = note

    @property
    def amount(self):
        """Gets the amount of this PayoutRequestPayoutData.  # noqa: E501

        Represents the amount to be transferred to Customer's card, must be less than 100 millions.  # noqa: E501

        :return: The amount of this PayoutRequestPayoutData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PayoutRequestPayoutData.

        Represents the amount to be transferred to Customer's card, must be less than 100 millions.  # noqa: E501

        :param amount: The amount of this PayoutRequestPayoutData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this PayoutRequestPayoutData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of the payout transaction. Must match terminal currency  # noqa: E501

        :return: The currency of this PayoutRequestPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PayoutRequestPayoutData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of the payout transaction. Must match terminal currency  # noqa: E501

        :param currency: The currency of this PayoutRequestPayoutData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this PayoutRequestPayoutData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used *(for BANKCARD, QIWI, WEBMONEY and BITCOIN methods only)*  # noqa: E501

        :return: The dynamic_descriptor of this PayoutRequestPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this PayoutRequestPayoutData.

        Short description of the service or product, must be enabled by CardPay manager to be used *(for BANKCARD, QIWI, WEBMONEY and BITCOIN methods only)*  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this PayoutRequestPayoutData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def note(self):
        """Gets the note of this PayoutRequestPayoutData.  # noqa: E501

        Note about the payout, not shown to Customer  # noqa: E501

        :return: The note of this PayoutRequestPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this PayoutRequestPayoutData.

        Note about the payout, not shown to Customer  # noqa: E501

        :param note: The note of this PayoutRequestPayoutData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutRequestPayoutData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutRequestPayoutData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.flight import Flight  # noqa: F401,E501


class Flights(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "computerized_res_system": "str",
        "credit_reason_indicator": "str",
        "departure_date": "str",
        "flight": "list[Flight]",
        "is_restricted": "bool",
        "origination_code": "str",
        "passenger_name": "str",
        "ticket_change_indicator": "str",
        "ticket_number": "str",
        "travel_agency_code": "str",
        "travel_agency_name": "str",
    }

    attribute_map = {
        "computerized_res_system": "computerized_res_system",
        "credit_reason_indicator": "credit_reason_indicator",
        "departure_date": "departure_date",
        "flight": "flight",
        "is_restricted": "is_restricted",
        "origination_code": "origination_code",
        "passenger_name": "passenger_name",
        "ticket_change_indicator": "ticket_change_indicator",
        "ticket_number": "ticket_number",
        "travel_agency_code": "travel_agency_code",
        "travel_agency_name": "travel_agency_name",
    }

    def __init__(
        self,
        computerized_res_system=None,
        credit_reason_indicator=None,
        departure_date=None,
        flight=None,
        is_restricted=None,
        origination_code=None,
        passenger_name=None,
        ticket_change_indicator=None,
        ticket_number=None,
        travel_agency_code=None,
        travel_agency_name=None,
    ):  # noqa: E501
        """Flights - a model defined in Swagger"""  # noqa: E501

        self._computerized_res_system = None
        self._credit_reason_indicator = None
        self._departure_date = None
        self._flight = None
        self._is_restricted = None
        self._origination_code = None
        self._passenger_name = None
        self._ticket_change_indicator = None
        self._ticket_number = None
        self._travel_agency_code = None
        self._travel_agency_name = None
        self.discriminator = None

        if computerized_res_system is not None:
            self.computerized_res_system = computerized_res_system
        if credit_reason_indicator is not None:
            self.credit_reason_indicator = credit_reason_indicator
        if departure_date is not None:
            self.departure_date = departure_date
        if flight is not None:
            self.flight = flight
        if is_restricted is not None:
            self.is_restricted = is_restricted
        if origination_code is not None:
            self.origination_code = origination_code
        if passenger_name is not None:
            self.passenger_name = passenger_name
        if ticket_change_indicator is not None:
            self.ticket_change_indicator = ticket_change_indicator
        if ticket_number is not None:
            self.ticket_number = ticket_number
        if travel_agency_code is not None:
            self.travel_agency_code = travel_agency_code
        if travel_agency_name is not None:
            self.travel_agency_name = travel_agency_name

    @property
    def computerized_res_system(self):
        """Gets the computerized_res_system of this Flights.  # noqa: E501

        Computerized reservation system code  # noqa: E501

        :return: The computerized_res_system of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._computerized_res_system

    @computerized_res_system.setter
    def computerized_res_system(self, computerized_res_system):
        """Sets the computerized_res_system of this Flights.

        Computerized reservation system code  # noqa: E501

        :param computerized_res_system: The computerized_res_system of this Flights.  # noqa: E501
        :type: str
        """
        if computerized_res_system is not None and len(computerized_res_system) > 4:
            raise ValueError(
                "Invalid value for `computerized_res_system`, length must be less than or equal to `4`"
            )  # noqa: E501
        if computerized_res_system is not None and len(computerized_res_system) < 0:
            raise ValueError(
                "Invalid value for `computerized_res_system`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._computerized_res_system = computerized_res_system

    @property
    def credit_reason_indicator(self):
        """Gets the credit_reason_indicator of this Flights.  # noqa: E501

        Credit reason indicator  # noqa: E501

        :return: The credit_reason_indicator of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._credit_reason_indicator

    @credit_reason_indicator.setter
    def credit_reason_indicator(self, credit_reason_indicator):
        """Sets the credit_reason_indicator of this Flights.

        Credit reason indicator  # noqa: E501

        :param credit_reason_indicator: The credit_reason_indicator of this Flights.  # noqa: E501
        :type: str
        """
        if credit_reason_indicator is not None and len(credit_reason_indicator) > 1:
            raise ValueError(
                "Invalid value for `credit_reason_indicator`, length must be less than or equal to `1`"
            )  # noqa: E501
        if credit_reason_indicator is not None and len(credit_reason_indicator) < 1:
            raise ValueError(
                "Invalid value for `credit_reason_indicator`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._credit_reason_indicator = credit_reason_indicator

    @property
    def departure_date(self):
        """Gets the departure_date of this Flights.  # noqa: E501

        Date of departure in format 'DD.MM.YYYY'  # noqa: E501

        :return: The departure_date of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._departure_date

    @departure_date.setter
    def departure_date(self, departure_date):
        """Sets the departure_date of this Flights.

        Date of departure in format 'DD.MM.YYYY'  # noqa: E501

        :param departure_date: The departure_date of this Flights.  # noqa: E501
        :type: str
        """

        self._departure_date = departure_date

    @property
    def flight(self):
        """Gets the flight of this Flights.  # noqa: E501

        Information about particular flight legs, shouldn't have more than 4 flight subsections in one flights section.  # noqa: E501

        :return: The flight of this Flights.  # noqa: E501
        :rtype: list[Flight]
        """
        return self._flight

    @flight.setter
    def flight(self, flight):
        """Sets the flight of this Flights.

        Information about particular flight legs, shouldn't have more than 4 flight subsections in one flights section.  # noqa: E501

        :param flight: The flight of this Flights.  # noqa: E501
        :type: list[Flight]
        """

        self._flight = flight

    @property
    def is_restricted(self):
        """Gets the is_restricted of this Flights.  # noqa: E501

        Restricted ticket indicator  # noqa: E501

        :return: The is_restricted of this Flights.  # noqa: E501
        :rtype: bool
        """
        return self._is_restricted

    @is_restricted.setter
    def is_restricted(self, is_restricted):
        """Sets the is_restricted of this Flights.

        Restricted ticket indicator  # noqa: E501

        :param is_restricted: The is_restricted of this Flights.  # noqa: E501
        :type: bool
        """

        self._is_restricted = is_restricted

    @property
    def origination_code(self):
        """Gets the origination_code of this Flights.  # noqa: E501

        Code of airport of departure, IATA code  # noqa: E501

        :return: The origination_code of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._origination_code

    @origination_code.setter
    def origination_code(self, origination_code):
        """Sets the origination_code of this Flights.

        Code of airport of departure, IATA code  # noqa: E501

        :param origination_code: The origination_code of this Flights.  # noqa: E501
        :type: str
        """
        if origination_code is not None and len(origination_code) > 3:
            raise ValueError(
                "Invalid value for `origination_code`, length must be less than or equal to `3`"
            )  # noqa: E501
        if origination_code is not None and len(origination_code) < 3:
            raise ValueError(
                "Invalid value for `origination_code`, length must be greater than or equal to `3`"
            )  # noqa: E501

        self._origination_code = origination_code

    @property
    def passenger_name(self):
        """Gets the passenger_name of this Flights.  # noqa: E501

        First and last name of a passenger  # noqa: E501

        :return: The passenger_name of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._passenger_name

    @passenger_name.setter
    def passenger_name(self, passenger_name):
        """Sets the passenger_name of this Flights.

        First and last name of a passenger  # noqa: E501

        :param passenger_name: The passenger_name of this Flights.  # noqa: E501
        :type: str
        """
        if passenger_name is not None and len(passenger_name) > 20:
            raise ValueError(
                "Invalid value for `passenger_name`, length must be less than or equal to `20`"
            )  # noqa: E501
        if passenger_name is not None and len(passenger_name) < 0:
            raise ValueError(
                "Invalid value for `passenger_name`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._passenger_name = passenger_name

    @property
    def ticket_change_indicator(self):
        """Gets the ticket_change_indicator of this Flights.  # noqa: E501

        Ticket change indicator  # noqa: E501

        :return: The ticket_change_indicator of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._ticket_change_indicator

    @ticket_change_indicator.setter
    def ticket_change_indicator(self, ticket_change_indicator):
        """Sets the ticket_change_indicator of this Flights.

        Ticket change indicator  # noqa: E501

        :param ticket_change_indicator: The ticket_change_indicator of this Flights.  # noqa: E501
        :type: str
        """
        if ticket_change_indicator is not None and len(ticket_change_indicator) > 1:
            raise ValueError(
                "Invalid value for `ticket_change_indicator`, length must be less than or equal to `1`"
            )  # noqa: E501
        if ticket_change_indicator is not None and len(ticket_change_indicator) < 1:
            raise ValueError(
                "Invalid value for `ticket_change_indicator`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._ticket_change_indicator = ticket_change_indicator

    @property
    def ticket_number(self):
        """Gets the ticket_number of this Flights.  # noqa: E501

        Ticket number  # noqa: E501

        :return: The ticket_number of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._ticket_number

    @ticket_number.setter
    def ticket_number(self, ticket_number):
        """Sets the ticket_number of this Flights.

        Ticket number  # noqa: E501

        :param ticket_number: The ticket_number of this Flights.  # noqa: E501
        :type: str
        """
        if ticket_number is not None and len(ticket_number) > 15:
            raise ValueError(
                "Invalid value for `ticket_number`, length must be less than or equal to `15`"
            )  # noqa: E501
        if ticket_number is not None and len(ticket_number) < 0:
            raise ValueError(
                "Invalid value for `ticket_number`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._ticket_number = ticket_number

    @property
    def travel_agency_code(self):
        """Gets the travel_agency_code of this Flights.  # noqa: E501

        Code of travel agency  # noqa: E501

        :return: The travel_agency_code of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._travel_agency_code

    @travel_agency_code.setter
    def travel_agency_code(self, travel_agency_code):
        """Sets the travel_agency_code of this Flights.

        Code of travel agency  # noqa: E501

        :param travel_agency_code: The travel_agency_code of this Flights.  # noqa: E501
        :type: str
        """
        if travel_agency_code is not None and len(travel_agency_code) > 8:
            raise ValueError(
                "Invalid value for `travel_agency_code`, length must be less than or equal to `8`"
            )  # noqa: E501
        if travel_agency_code is not None and len(travel_agency_code) < 0:
            raise ValueError(
                "Invalid value for `travel_agency_code`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._travel_agency_code = travel_agency_code

    @property
    def travel_agency_name(self):
        """Gets the travel_agency_name of this Flights.  # noqa: E501

        Name of travel agency using only latin alphabet  # noqa: E501

        :return: The travel_agency_name of this Flights.  # noqa: E501
        :rtype: str
        """
        return self._travel_agency_name

    @travel_agency_name.setter
    def travel_agency_name(self, travel_agency_name):
        """Sets the travel_agency_name of this Flights.

        Name of travel agency using only latin alphabet  # noqa: E501

        :param travel_agency_name: The travel_agency_name of this Flights.  # noqa: E501
        :type: str
        """
        if travel_agency_name is not None and len(travel_agency_name) > 25:
            raise ValueError(
                "Invalid value for `travel_agency_name`, length must be less than or equal to `25`"
            )  # noqa: E501
        if travel_agency_name is not None and len(travel_agency_name) < 0:
            raise ValueError(
                "Invalid value for `travel_agency_name`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._travel_agency_name = travel_agency_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(Flights, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Flights):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentRequestPaymentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "authentication_request": "bool",
        "currency": "str",
        "dynamic_descriptor": "str",
        "encrypted_data": "str",
        "generate_token": "bool",
        "note": "str",
        "preauth": "bool",
        "trans_type": "str",
    }

    attribute_map = {
        "amount": "amount",
        "authentication_request": "authentication_request",
        "currency": "currency",
        "dynamic_descriptor": "dynamic_descriptor",
        "encrypted_data": "encrypted_data",
        "generate_token": "generate_token",
        "note": "note",
        "preauth": "preauth",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        amount=None,
        authentication_request=None,
        currency=None,
        dynamic_descriptor=None,
        encrypted_data=None,
        generate_token=None,
        note=None,
        preauth=None,
        trans_type=None,
    ):  # noqa: E501
        """PaymentRequestPaymentData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._authentication_request = None
        self._currency = None
        self._dynamic_descriptor = None
        self._encrypted_data = None
        self._generate_token = None
        self._note = None
        self._preauth = None
        self._trans_type = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if authentication_request is not None:
            self.authentication_request = authentication_request
        self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if encrypted_data is not None:
            self.encrypted_data = encrypted_data
        if generate_token is not None:
            self.generate_token = generate_token
        if note is not None:
            self.note = note
        if preauth is not None:
            self.preauth = preauth
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def amount(self):
        """Gets the amount of this PaymentRequestPaymentData.  # noqa: E501

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions If 'payment_method' = `BITCOIN` then minimum order amount is approximately 0.003 bitcoins or its equivalent. The exact value should be provided by the account manager.  # noqa: E501

        :return: The amount of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentRequestPaymentData.

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions If 'payment_method' = `BITCOIN` then minimum order amount is approximately 0.003 bitcoins or its equivalent. The exact value should be provided by the account manager.  # noqa: E501

        :param amount: The amount of this PaymentRequestPaymentData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def authentication_request(self):
        """Gets the authentication_request of this PaymentRequestPaymentData.  # noqa: E501

        If set to `true`, amount must not be presented in request, no payment will be made, only cardholder authentication will be performed. Also can be used to generate token. *(for BANKCARD payment method only)*  # noqa: E501

        :return: The authentication_request of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: bool
        """
        return self._authentication_request

    @authentication_request.setter
    def authentication_request(self, authentication_request):
        """Sets the authentication_request of this PaymentRequestPaymentData.

        If set to `true`, amount must not be presented in request, no payment will be made, only cardholder authentication will be performed. Also can be used to generate token. *(for BANKCARD payment method only)*  # noqa: E501

        :param authentication_request: The authentication_request of this PaymentRequestPaymentData.  # noqa: E501
        :type: bool
        """

        self._authentication_request = authentication_request

    @property
    def currency(self):
        """Gets the currency of this PaymentRequestPaymentData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PaymentRequestPaymentData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this PaymentRequestPaymentData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this PaymentRequestPaymentData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used *(for BANKCARD payment method only)*  # noqa: E501

        :return: The dynamic_descriptor of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this PaymentRequestPaymentData.

        Short description of the service or product, must be enabled by CardPay manager to be used *(for BANKCARD payment method only)*  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this PaymentRequestPaymentData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def encrypted_data(self):
        """Gets the encrypted_data of this PaymentRequestPaymentData.  # noqa: E501

        The encrypted payment credentials encoded in base64. *(for APPLEPAY payment method only)*  # noqa: E501

        :return: The encrypted_data of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._encrypted_data

    @encrypted_data.setter
    def encrypted_data(self, encrypted_data):
        """Sets the encrypted_data of this PaymentRequestPaymentData.

        The encrypted payment credentials encoded in base64. *(for APPLEPAY payment method only)*  # noqa: E501

        :param encrypted_data: The encrypted_data of this PaymentRequestPaymentData.  # noqa: E501
        :type: str
        """
        if encrypted_data is not None and len(encrypted_data) > 10000:
            raise ValueError(
                "Invalid value for `encrypted_data`, length must be less than or equal to `10000`"
            )  # noqa: E501
        if encrypted_data is not None and len(encrypted_data) < 0:
            raise ValueError(
                "Invalid value for `encrypted_data`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._encrypted_data = encrypted_data

    @property
    def generate_token(self):
        """Gets the generate_token of this PaymentRequestPaymentData.  # noqa: E501

        If set to `true`, token will be generated and returned in the response. Token can be generated only for successful transactions (not for declined transactions) *(for BANKCARD payment method only)*  # noqa: E501

        :return: The generate_token of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: bool
        """
        return self._generate_token

    @generate_token.setter
    def generate_token(self, generate_token):
        """Sets the generate_token of this PaymentRequestPaymentData.

        If set to `true`, token will be generated and returned in the response. Token can be generated only for successful transactions (not for declined transactions) *(for BANKCARD payment method only)*  # noqa: E501

        :param generate_token: The generate_token of this PaymentRequestPaymentData.  # noqa: E501
        :type: bool
        """

        self._generate_token = generate_token

    @property
    def note(self):
        """Gets the note of this PaymentRequestPaymentData.  # noqa: E501

        Note about the transaction that will not be displayed to Customer  # noqa: E501

        :return: The note of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this PaymentRequestPaymentData.

        Note about the transaction that will not be displayed to Customer  # noqa: E501

        :param note: The note of this PaymentRequestPaymentData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    @property
    def preauth(self):
        """Gets the preauth of this PaymentRequestPaymentData.  # noqa: E501

        If set to `true`, the amount will not be captured but only blocked. Payments with 'preauth' attribute will be captured automatically in 7 days from the time of creating the preauth transaction. *(for BANKCARD payment method only)*.  # noqa: E501

        :return: The preauth of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: bool
        """
        return self._preauth

    @preauth.setter
    def preauth(self, preauth):
        """Sets the preauth of this PaymentRequestPaymentData.

        If set to `true`, the amount will not be captured but only blocked. Payments with 'preauth' attribute will be captured automatically in 7 days from the time of creating the preauth transaction. *(for BANKCARD payment method only)*.  # noqa: E501

        :param preauth: The preauth of this PaymentRequestPaymentData.  # noqa: E501
        :type: bool
        """

        self._preauth = preauth

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this PaymentRequestPaymentData.  # noqa: E501


        :return: The trans_type of this PaymentRequestPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this PaymentRequestPaymentData.


        :param trans_type: The trans_type of this PaymentRequestPaymentData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentRequestPaymentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestPaymentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FilterParameters(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request_id": "str",
        "merchant_order_id": "str",
        "payment_method": "str",
        "start_time": "datetime",
        "end_time": "datetime",
        "max_count": "int",
        "sort_order": "str",
        "currency": "str",
    }

    attribute_map = {
        "request_id": "request_id",
        "merchant_order_id": "merchant_order_id",
        "payment_method": "payment_method",
        "start_time": "start_time",
        "end_time": "end_time",
        "max_count": "max_count",
        "sort_order": "sort_order",
        "currency": "currency",
    }

    def __init__(
        self,
        request_id=None,
        merchant_order_id=None,
        payment_method=None,
        start_time=None,
        end_time=None,
        max_count=None,
        sort_order=None,
        currency=None,
    ):  # noqa: E501
        """FilterParameters - a model defined in Swagger"""  # noqa: E501

        self._request_id = None
        self._merchant_order_id = None
        self._payment_method = None
        self._start_time = None
        self._end_time = None
        self._max_count = None
        self._sort_order = None
        self._currency = None
        self.discriminator = None

        self.request_id = request_id
        if merchant_order_id is not None:
            self.merchant_order_id = merchant_order_id
        if payment_method is not None:
            self.payment_method = payment_method
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if max_count is not None:
            self.max_count = max_count
        if sort_order is not None:
            self.sort_order = sort_order
        if currency is not None:
            self.currency = currency

    @property
    def request_id(self):
        """Gets the request_id of this FilterParameters.  # noqa: E501

        Request ID  # noqa: E501

        :return: The request_id of this FilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this FilterParameters.

        Request ID  # noqa: E501

        :param request_id: The request_id of this FilterParameters.  # noqa: E501
        :type: str
        """
        if request_id is None:
            raise ValueError(
                "Invalid value for `request_id`, must not be `None`"
            )  # noqa: E501
        if request_id is not None and len(request_id) > 50:
            raise ValueError(
                "Invalid value for `request_id`, length must be less than or equal to `50`"
            )  # noqa: E501
        if request_id is not None and len(request_id) < 0:
            raise ValueError(
                "Invalid value for `request_id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._request_id = request_id

    @property
    def merchant_order_id(self):
        """Gets the merchant_order_id of this FilterParameters.  # noqa: E501

        Merchant order number from the merchant system  # noqa: E501

        :return: The merchant_order_id of this FilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._merchant_order_id

    @merchant_order_id.setter
    def merchant_order_id(self, merchant_order_id):
        """Sets the merchant_order_id of this FilterParameters.

        Merchant order number from the merchant system  # noqa: E501

        :param merchant_order_id: The merchant_order_id of this FilterParameters.  # noqa: E501
        :type: str
        """
        if merchant_order_id is not None and len(merchant_order_id) > 50:
            raise ValueError(
                "Invalid value for `merchant_order_id`, length must be less than or equal to `50`"
            )  # noqa: E501
        if merchant_order_id is not None and len(merchant_order_id) < 0:
            raise ValueError(
                "Invalid value for `merchant_order_id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._merchant_order_id = merchant_order_id

    @property
    def payment_method(self):
        """Gets the payment_method of this FilterParameters.  # noqa: E501

        Used payment method type name from payment methods list  # noqa: E501

        :return: The payment_method of this FilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this FilterParameters.

        Used payment method type name from payment methods list  # noqa: E501

        :param payment_method: The payment_method of this FilterParameters.  # noqa: E501
        :type: str
        """
        if payment_method is not None and len(payment_method) > 100:
            raise ValueError(
                "Invalid value for `payment_method`, length must be less than or equal to `100`"
            )  # noqa: E501
        if payment_method is not None and len(payment_method) < 0:
            raise ValueError(
                "Invalid value for `payment_method`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._payment_method = payment_method

    @property
    def start_time(self):
        """Gets the start_time of this FilterParameters.  # noqa: E501

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The start_time of this FilterParameters.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this FilterParameters.

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param start_time: The start_time of this FilterParameters.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this FilterParameters.  # noqa: E501

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The end_time of this FilterParameters.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this FilterParameters.

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param end_time: The end_time of this FilterParameters.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def max_count(self):
        """Gets the max_count of this FilterParameters.  # noqa: E501

        Limit number of returned transactions (must be less than 10000, default is 1000)  # noqa: E501

        :return: The max_count of this FilterParameters.  # noqa: E501
        :rtype: int
        """
        return self._max_count

    @max_count.setter
    def max_count(self, max_count):
        """Sets the max_count of this FilterParameters.

        Limit number of returned transactions (must be less than 10000, default is 1000)  # noqa: E501

        :param max_count: The max_count of this FilterParameters.  # noqa: E501
        :type: int
        """
        if max_count is not None and max_count > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for `max_count`, must be a value less than or equal to `10000`"
            )  # noqa: E501

        self._max_count = max_count

    class SortOrder(object):
        ASC = "asc"
        DESC = "desc"

    @property
    def sort_order(self):
        """Gets the sort_order of this FilterParameters.  # noqa: E501

        Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)  # noqa: E501

        :return: The sort_order of this FilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this FilterParameters.

        Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)  # noqa: E501

        :param sort_order: The sort_order of this FilterParameters.  # noqa: E501
        :type: str
        """
        allowed_values = ["asc", "desc"]  # noqa: E501
        if sort_order not in allowed_values:
            raise ValueError(
                "Invalid value for `sort_order` ({0}), must be one of {1}".format(  # noqa: E501
                    sort_order, allowed_values
                )
            )

        self._sort_order = sort_order

    @property
    def currency(self):
        """Gets the currency of this FilterParameters.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency  # noqa: E501

        :return: The currency of this FilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this FilterParameters.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency  # noqa: E501

        :param currency: The currency of this FilterParameters.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(FilterParameters, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentResponseCryptocurrencyAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "crypto_address": "str",
        "crypto_transaction_id": "str",
        "prc_amount": "float",
        "prc_currency": "str",
    }

    attribute_map = {
        "crypto_address": "crypto_address",
        "crypto_transaction_id": "crypto_transaction_id",
        "prc_amount": "prc_amount",
        "prc_currency": "prc_currency",
    }

    def __init__(
        self,
        crypto_address=None,
        crypto_transaction_id=None,
        prc_amount=None,
        prc_currency=None,
    ):  # noqa: E501
        """PaymentResponseCryptocurrencyAccount - a model defined in Swagger"""  # noqa: E501

        self._crypto_address = None
        self._crypto_transaction_id = None
        self._prc_amount = None
        self._prc_currency = None
        self.discriminator = None

        if crypto_address is not None:
            self.crypto_address = crypto_address
        if crypto_transaction_id is not None:
            self.crypto_transaction_id = crypto_transaction_id
        if prc_amount is not None:
            self.prc_amount = prc_amount
        if prc_currency is not None:
            self.prc_currency = prc_currency

    @property
    def crypto_address(self):
        """Gets the crypto_address of this PaymentResponseCryptocurrencyAccount.  # noqa: E501

        Bitcoin address for created transaction  # noqa: E501

        :return: The crypto_address of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :rtype: str
        """
        return self._crypto_address

    @crypto_address.setter
    def crypto_address(self, crypto_address):
        """Sets the crypto_address of this PaymentResponseCryptocurrencyAccount.

        Bitcoin address for created transaction  # noqa: E501

        :param crypto_address: The crypto_address of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :type: str
        """

        self._crypto_address = crypto_address

    @property
    def crypto_transaction_id(self):
        """Gets the crypto_transaction_id of this PaymentResponseCryptocurrencyAccount.  # noqa: E501

        Id of created transaction in the bitcoin system  # noqa: E501

        :return: The crypto_transaction_id of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :rtype: str
        """
        return self._crypto_transaction_id

    @crypto_transaction_id.setter
    def crypto_transaction_id(self, crypto_transaction_id):
        """Sets the crypto_transaction_id of this PaymentResponseCryptocurrencyAccount.

        Id of created transaction in the bitcoin system  # noqa: E501

        :param crypto_transaction_id: The crypto_transaction_id of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :type: str
        """

        self._crypto_transaction_id = crypto_transaction_id

    @property
    def prc_amount(self):
        """Gets the prc_amount of this PaymentResponseCryptocurrencyAccount.  # noqa: E501

        Transaction amount (only for FIAT-BTC scenario)  # noqa: E501

        :return: The prc_amount of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :rtype: float
        """
        return self._prc_amount

    @prc_amount.setter
    def prc_amount(self, prc_amount):
        """Sets the prc_amount of this PaymentResponseCryptocurrencyAccount.

        Transaction amount (only for FIAT-BTC scenario)  # noqa: E501

        :param prc_amount: The prc_amount of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :type: float
        """

        self._prc_amount = prc_amount

    @property
    def prc_currency(self):
        """Gets the prc_currency of this PaymentResponseCryptocurrencyAccount.  # noqa: E501

        Currency of transaction (only for FIAT-BTC scenario)  # noqa: E501

        :return: The prc_currency of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :rtype: str
        """
        return self._prc_currency

    @prc_currency.setter
    def prc_currency(self, prc_currency):
        """Sets the prc_currency of this PaymentResponseCryptocurrencyAccount.

        Currency of transaction (only for FIAT-BTC scenario)  # noqa: E501

        :param prc_currency: The prc_currency of this PaymentResponseCryptocurrencyAccount.  # noqa: E501
        :type: str
        """

        self._prc_currency = prc_currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentResponseCryptocurrencyAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentResponseCryptocurrencyAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.recurring_request_filing import (
    RecurringRequestFiling,
)  # noqa: F401,E501


class OneclickData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "currency": "str",
        "dynamic_descriptor": "str",
        "filing": "RecurringRequestFiling",
        "generate_token": "bool",
        "initiator": "str",
        "note": "str",
        "preauth": "bool",
        "trans_type": "str",
    }

    attribute_map = {
        "amount": "amount",
        "currency": "currency",
        "dynamic_descriptor": "dynamic_descriptor",
        "filing": "filing",
        "generate_token": "generate_token",
        "initiator": "initiator",
        "note": "note",
        "preauth": "preauth",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        amount=None,
        currency=None,
        dynamic_descriptor=None,
        filing=None,
        generate_token=None,
        initiator=None,
        note=None,
        preauth=None,
        trans_type=None,
    ):  # noqa: E501
        """OneclickData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self._dynamic_descriptor = None
        self._filing = None
        self._generate_token = None
        self._initiator = None
        self._note = None
        self._preauth = None
        self._trans_type = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if filing is not None:
            self.filing = filing
        if generate_token is not None:
            self.generate_token = generate_token
        self.initiator = initiator
        if note is not None:
            self.note = note
        if preauth is not None:
            self.preauth = preauth
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def amount(self):
        """Gets the amount of this OneclickData.  # noqa: E501

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :return: The amount of this OneclickData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this OneclickData.

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :param amount: The amount of this OneclickData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this OneclickData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this OneclickData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this OneclickData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this OneclickData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this OneclickData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :return: The dynamic_descriptor of this OneclickData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this OneclickData.

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this OneclickData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def filing(self):
        """Gets the filing of this OneclickData.  # noqa: E501

        Filing data, should be send in all recurring requests besides first recurring request First recurring request should be send without filing attribute  # noqa: E501

        :return: The filing of this OneclickData.  # noqa: E501
        :rtype: RecurringRequestFiling
        """
        return self._filing

    @filing.setter
    def filing(self, filing):
        """Sets the filing of this OneclickData.

        Filing data, should be send in all recurring requests besides first recurring request First recurring request should be send without filing attribute  # noqa: E501

        :param filing: The filing of this OneclickData.  # noqa: E501
        :type: RecurringRequestFiling
        """

        self._filing = filing

    @property
    def generate_token(self):
        """Gets the generate_token of this OneclickData.  # noqa: E501

        This attribute can be received only in first recurring request. If set to 'true', Card token will be generated and returned in GET response for all successful transactions (can't be generated for declined transactions). In all requests with filing_id card.token can't be generated.  # noqa: E501

        :return: The generate_token of this OneclickData.  # noqa: E501
        :rtype: bool
        """
        return self._generate_token

    @generate_token.setter
    def generate_token(self, generate_token):
        """Sets the generate_token of this OneclickData.

        This attribute can be received only in first recurring request. If set to 'true', Card token will be generated and returned in GET response for all successful transactions (can't be generated for declined transactions). In all requests with filing_id card.token can't be generated.  # noqa: E501

        :param generate_token: The generate_token of this OneclickData.  # noqa: E501
        :type: bool
        """

        self._generate_token = generate_token

    @property
    def initiator(self):
        """Gets the initiator of this OneclickData.  # noqa: E501

        Can be only 2 values - 'mit' (merchant initiated transaction), 'cit' (cardholder initiated transaction).  # noqa: E501

        :return: The initiator of this OneclickData.  # noqa: E501
        :rtype: str
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this OneclickData.

        Can be only 2 values - 'mit' (merchant initiated transaction), 'cit' (cardholder initiated transaction).  # noqa: E501

        :param initiator: The initiator of this OneclickData.  # noqa: E501
        :type: str
        """
        if initiator is None:
            raise ValueError(
                "Invalid value for `initiator`, must not be `None`"
            )  # noqa: E501
        if initiator is not None and not re.search(r"mit|cit", initiator):  # noqa: E501
            raise ValueError(
                r"Invalid value for `initiator`, must be a follow pattern or equal to `/mit|cit/`"
            )  # noqa: E501

        self._initiator = initiator

    @property
    def note(self):
        """Gets the note of this OneclickData.  # noqa: E501

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :return: The note of this OneclickData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this OneclickData.

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :param note: The note of this OneclickData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    @property
    def preauth(self):
        """Gets the preauth of this OneclickData.  # noqa: E501

        This parameter allowed to be used only for first recurring payment. If set to 'true', the amount will not be captured but only blocked. One-click payments with 'preauth' attribute will be captured automatically in 7 days from the time of creating the preauth transaction. In continue recurring request (with 'filing_id') this parameter shouldn't be used.  # noqa: E501

        :return: The preauth of this OneclickData.  # noqa: E501
        :rtype: bool
        """
        return self._preauth

    @preauth.setter
    def preauth(self, preauth):
        """Sets the preauth of this OneclickData.

        This parameter allowed to be used only for first recurring payment. If set to 'true', the amount will not be captured but only blocked. One-click payments with 'preauth' attribute will be captured automatically in 7 days from the time of creating the preauth transaction. In continue recurring request (with 'filing_id') this parameter shouldn't be used.  # noqa: E501

        :param preauth: The preauth of this OneclickData.  # noqa: E501
        :type: bool
        """

        self._preauth = preauth

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this OneclickData.  # noqa: E501


        :return: The trans_type of this OneclickData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this OneclickData.


        :param trans_type: The trans_type of this OneclickData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(OneclickData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OneclickData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import copy
import logging
import multiprocessing
import sys
import urllib3

import six
from six.moves import http_client as httplib


class Configuration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Ref: https://github.com/swagger-api/swagger-codegen
    Do not edit the class manually.
    """

    _default = None

    def __init__(self, base_url=None, terminal_code=None, password=None, debug=False):
        """Constructor"""
        if self._default:
            for key in self._default.__dict__.keys():
                self.__dict__[key] = copy.copy(self._default.__dict__[key])
            return

        # Default Base url
        self.base_url = base_url

        self.terminal_code = terminal_code
        self.password = password

        # Temp file folder for downloading files
        self.temp_folder_path = None

        # Authentication Settings
        # dict to store API key(s)
        self.api_key = {}
        # dict to store API prefix (e.g. Bearer)
        self.api_key_prefix = {}

        # Logging Settings
        self.logger = {
            "package_logger": logging.getLogger("cardpay"),
            "urllib3_logger": logging.getLogger("urllib3"),
        }
        # Log format
        self.logger_format = "%(asctime)s %(levelname)s %(message)s"
        # Log stream handler
        self.logger_stream_handler = None
        # Log file handler
        self.logger_file_handler = None
        # Debug file location
        self.logger_file = None
        # Debug switch
        self.debug = debug

        # SSL/TLS verification
        # Set this to false to skip verifying SSL certificate when calling API
        # from https server.
        self.verify_ssl = True
        # Set this to customize the certificate file to verify the peer.
        self.ssl_ca_cert = None
        # client certificate file
        self.cert_file = None
        # client key file
        self.key_file = None
        # Set this to True/False to enable/disable SSL hostname verification.
        self.assert_hostname = None

        # urllib3 connection pool's maximum number of connections saved
        # per pool. urllib3 uses 1 connection as default value, but this is
        # not the best value when you are making a lot of possibly parallel
        # requests to the same host, which is often the case here.
        # cpu_count * 5 is used as default value to increase performance.
        self.connection_pool_maxsize = multiprocessing.cpu_count() * 5

        # Proxy URL
        self.proxy = None
        # Safe chars for path_param
        self.safe_chars_for_path_param = ""

    @classmethod
    def set_default(cls, default):
        cls._default = default

    @property
    def logger_file(self):
        """The logger file.

        If the logger_file is None, then add stream handler and remove file
        handler. Otherwise, add file handler and remove stream handler.

        :param value: The logger_file path.
        :type: str
        """
        return self.__logger_file

    @logger_file.setter
    def logger_file(self, value):
        """The logger file.

        If the logger_file is None, then add stream handler and remove file
        handler. Otherwise, add file handler and remove stream handler.

        :param value: The logger_file path.
        :type: str
        """
        self.__logger_file = value
        if self.__logger_file:
            # If set logging file,
            # then add file handler and remove stream handler.
            self.logger_file_handler = logging.FileHandler(self.__logger_file)
            self.logger_file_handler.setFormatter(self.logger_formatter)
            for _, logger in six.iteritems(self.logger):
                logger.addHandler(self.logger_file_handler)
                if self.logger_stream_handler:
                    logger.removeHandler(self.logger_stream_handler)
        else:
            # If not set logging file,
            # then add stream handler and remove file handler.
            self.logger_stream_handler = logging.StreamHandler()
            self.logger_stream_handler.setFormatter(self.logger_formatter)
            for _, logger in six.iteritems(self.logger):
                logger.addHandler(self.logger_stream_handler)
                if self.logger_file_handler:
                    logger.removeHandler(self.logger_file_handler)

    @property
    def debug(self):
        """Debug status

        :param value: The debug status, True or False.
        :type: bool
        """
        return self.__debug

    @debug.setter
    def debug(self, value):
        """Debug status

        :param value: The debug status, True or False.
        :type: bool
        """
        self.__debug = value
        if self.__debug:
            # if debug status is True, turn on debug logging
            for _, logger in six.iteritems(self.logger):
                logger.setLevel(logging.DEBUG)
            # turn on httplib debug
            httplib.HTTPConnection.debuglevel = 1
        else:
            # if debug status is False, turn off debug logging,
            # setting log level to default `logging.WARNING`
            for _, logger in six.iteritems(self.logger):
                logger.setLevel(logging.WARNING)
            # turn off httplib debug
            httplib.HTTPConnection.debuglevel = 0

    @property
    def logger_format(self):
        """The logger format.

        The logger_formatter will be updated when sets logger_format.

        :param value: The format string.
        :type: str
        """
        return self.__logger_format

    @logger_format.setter
    def logger_format(self, value):
        """The logger format.

        The logger_formatter will be updated when sets logger_format.

        :param value: The format string.
        :type: str
        """
        self.__logger_format = value
        self.logger_formatter = logging.Formatter(self.__logger_format)

    def to_debug_report(self):
        """Gets the essential information for debugging.

        :return: The report for debugging.
        """
        return (
            "Python SDK Debug Report:\n"
            "OS: {env}\n"
            "Python Version: {pyversion}\n"
            "Version of the API: 3.0\n"
            "SDK Package Version: 1.9.0.12".format(
                env=sys.platform, pyversion=sys.version
            )
        )



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiTokens(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "access_token": "str",
        "expires_in": "int",
        "refresh_expires_in": "int",
        "refresh_token": "str",
        "token_type": "str",
    }

    attribute_map = {
        "access_token": "access_token",
        "expires_in": "expires_in",
        "refresh_expires_in": "refresh_expires_in",
        "refresh_token": "refresh_token",
        "token_type": "token_type",
    }

    def __init__(
        self,
        access_token=None,
        expires_in=None,
        refresh_expires_in=None,
        refresh_token=None,
        token_type=None,
    ):  # noqa: E501
        """ApiTokens - a model defined in Swagger"""  # noqa: E501

        self._access_token = None
        self._expires_in = None
        self._refresh_expires_in = None
        self._refresh_token = None
        self._token_type = None
        self.discriminator = None

        self.access_token = access_token
        self.expires_in = expires_in
        self.refresh_expires_in = refresh_expires_in
        self.refresh_token = refresh_token
        self.token_type = token_type

    @property
    def access_token(self):
        """Gets the access_token of this ApiTokens.  # noqa: E501

        API access token which grants the access to the list of authorized services.  # noqa: E501

        :return: The access_token of this ApiTokens.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this ApiTokens.

        API access token which grants the access to the list of authorized services.  # noqa: E501

        :param access_token: The access_token of this ApiTokens.  # noqa: E501
        :type: str
        """
        if access_token is None:
            raise ValueError(
                "Invalid value for `access_token`, must not be `None`"
            )  # noqa: E501

        self._access_token = access_token

    @property
    def expires_in(self):
        """Gets the expires_in of this ApiTokens.  # noqa: E501

        Access token lifetime in seconds.  # noqa: E501

        :return: The expires_in of this ApiTokens.  # noqa: E501
        :rtype: int
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this ApiTokens.

        Access token lifetime in seconds.  # noqa: E501

        :param expires_in: The expires_in of this ApiTokens.  # noqa: E501
        :type: int
        """
        if expires_in is None:
            raise ValueError(
                "Invalid value for `expires_in`, must not be `None`"
            )  # noqa: E501

        self._expires_in = expires_in

    @property
    def refresh_expires_in(self):
        """Gets the refresh_expires_in of this ApiTokens.  # noqa: E501

        Refresh token lifetime in seconds.  # noqa: E501

        :return: The refresh_expires_in of this ApiTokens.  # noqa: E501
        :rtype: int
        """
        return self._refresh_expires_in

    @refresh_expires_in.setter
    def refresh_expires_in(self, refresh_expires_in):
        """Sets the refresh_expires_in of this ApiTokens.

        Refresh token lifetime in seconds.  # noqa: E501

        :param refresh_expires_in: The refresh_expires_in of this ApiTokens.  # noqa: E501
        :type: int
        """
        if refresh_expires_in is None:
            raise ValueError(
                "Invalid value for `refresh_expires_in`, must not be `None`"
            )  # noqa: E501

        self._refresh_expires_in = refresh_expires_in

    @property
    def refresh_token(self):
        """Gets the refresh_token of this ApiTokens.  # noqa: E501

        API refresh token that is used to update expired access token.  # noqa: E501

        :return: The refresh_token of this ApiTokens.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this ApiTokens.

        API refresh token that is used to update expired access token.  # noqa: E501

        :param refresh_token: The refresh_token of this ApiTokens.  # noqa: E501
        :type: str
        """
        if refresh_token is None:
            raise ValueError(
                "Invalid value for `refresh_token`, must not be `None`"
            )  # noqa: E501

        self._refresh_token = refresh_token

    @property
    def token_type(self):
        """Gets the token_type of this ApiTokens.  # noqa: E501

        Access token type  # noqa: E501

        :return: The token_type of this ApiTokens.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this ApiTokens.

        Access token type  # noqa: E501

        :param token_type: The token_type of this ApiTokens.  # noqa: E501
        :type: str
        """
        if token_type is None:
            raise ValueError(
                "Invalid value for `token_type`, must not be `None`"
            )  # noqa: E501

        self._token_type = token_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ApiTokens, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiTokens):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResponsePlanData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "created": "datetime",
        "status": "str",
        "period": "str",
        "interval": "int",
        "currency": "str",
        "amount": "float",
        "retries": "int",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "created": "created",
        "status": "status",
        "period": "period",
        "interval": "interval",
        "currency": "currency",
        "amount": "amount",
        "retries": "retries",
    }

    def __init__(
        self,
        id=None,
        name=None,
        created=None,
        status=None,
        period=None,
        interval=None,
        currency=None,
        amount=None,
        retries=None,
    ):  # noqa: E501
        """ResponsePlanData - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._created = None
        self._status = None
        self._period = None
        self._interval = None
        self._currency = None
        self._amount = None
        self._retries = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.created = created
        self.status = status
        self.period = period
        self.interval = interval
        self.currency = currency
        self.amount = amount
        if retries is not None:
            self.retries = retries

    @property
    def id(self):
        """Gets the id of this ResponsePlanData.  # noqa: E501

        ID of created plan  # noqa: E501

        :return: The id of this ResponsePlanData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponsePlanData.

        ID of created plan  # noqa: E501

        :param id: The id of this ResponsePlanData.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ResponsePlanData.  # noqa: E501

        Name of created plan  # noqa: E501

        :return: The name of this ResponsePlanData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponsePlanData.

        Name of created plan  # noqa: E501

        :param name: The name of this ResponsePlanData.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def created(self):
        """Gets the created of this ResponsePlanData.  # noqa: E501

        Creation time, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :return: The created of this ResponsePlanData.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ResponsePlanData.

        Creation time, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :param created: The created of this ResponsePlanData.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError(
                "Invalid value for `created`, must not be `None`"
            )  # noqa: E501

        self._created = created

    class Status(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"

    @property
    def status(self):
        """Gets the status of this ResponsePlanData.  # noqa: E501

        Status of created plan: 'ACTIVE' or 'INACTIVE'  # noqa: E501

        :return: The status of this ResponsePlanData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponsePlanData.

        Status of created plan: 'ACTIVE' or 'INACTIVE'  # noqa: E501

        :param status: The status of this ResponsePlanData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["ACTIVE", "INACTIVE"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    class Period(object):
        MINUTE = "minute"
        DAY = "day"
        WEEK = "week"
        MONTH = "month"
        YEAR = "year"

    @property
    def period(self):
        """Gets the period of this ResponsePlanData.  # noqa: E501

        Period of created plan  # noqa: E501

        :return: The period of this ResponsePlanData.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this ResponsePlanData.

        Period of created plan  # noqa: E501

        :param period: The period of this ResponsePlanData.  # noqa: E501
        :type: str
        """
        if period is None:
            raise ValueError(
                "Invalid value for `period`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["minute", "day", "week", "month", "year"]  # noqa: E501
        if period not in allowed_values:
            raise ValueError(
                "Invalid value for `period` ({0}), must be one of {1}".format(  # noqa: E501
                    period, allowed_values
                )
            )

        self._period = period

    @property
    def interval(self):
        """Gets the interval of this ResponsePlanData.  # noqa: E501

        Interval of plan  # noqa: E501

        :return: The interval of this ResponsePlanData.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this ResponsePlanData.

        Interval of plan  # noqa: E501

        :param interval: The interval of this ResponsePlanData.  # noqa: E501
        :type: int
        """
        if interval is None:
            raise ValueError(
                "Invalid value for `interval`, must not be `None`"
            )  # noqa: E501

        self._interval = interval

    @property
    def currency(self):
        """Gets the currency of this ResponsePlanData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of created plan  # noqa: E501

        :return: The currency of this ResponsePlanData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ResponsePlanData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of created plan  # noqa: E501

        :param currency: The currency of this ResponsePlanData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def amount(self):
        """Gets the amount of this ResponsePlanData.  # noqa: E501

        The total amount of created plan  # noqa: E501

        :return: The amount of this ResponsePlanData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ResponsePlanData.

        The total amount of created plan  # noqa: E501

        :param amount: The amount of this ResponsePlanData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def retries(self):
        """Gets the retries of this ResponsePlanData.  # noqa: E501

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts  # noqa: E501

        :return: The retries of this ResponsePlanData.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this ResponsePlanData.

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts  # noqa: E501

        :param retries: The retries of this ResponsePlanData.  # noqa: E501
        :type: int
        """

        self._retries = retries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ResponsePlanData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponsePlanData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

import os
from codecs import open
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
os.chdir(here)

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fp:
    long_description = fp.read()

setup(
    name="cardpay",
    version="1.9.0.12",
    description="Cardpay APIv3 Python SDK",
    author_email="",
    url="https://github.com/cardpay/python-sdk-v3.git",
    license="MIT",
    keywords=["cardpay", "APIv3", "CardPay REST API"],
    install_requires=[
        "certifi>=2017.4.17",
        "python-dateutil>=2.1",
        "six>=1.10",
        "urllib3>=1.23"
    ],
    packages=find_packages(exclude=["tests", "tests.*"]),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    project_urls={
        "Documentation": "https://integration.cardpay.com/v3/",
        "Source Code": "https://github.com/cardpay/python-sdk-v3",
    }
)



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Item(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "count": "int",
        "description": "str",
        "name": "str",
        "price": "float",
    }

    attribute_map = {
        "count": "count",
        "description": "description",
        "name": "name",
        "price": "price",
    }

    def __init__(
        self, count=None, description=None, name=None, price=None
    ):  # noqa: E501
        """Item - a model defined in Swagger"""  # noqa: E501

        self._count = None
        self._description = None
        self._name = None
        self._price = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if description is not None:
            self.description = description
        self.name = name
        if price is not None:
            self.price = price

    @property
    def count(self):
        """Gets the count of this Item.  # noqa: E501

        The count of product / service, provided to Customer. Any positive number  # noqa: E501

        :return: The count of this Item.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this Item.

        The count of product / service, provided to Customer. Any positive number  # noqa: E501

        :param count: The count of this Item.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def description(self):
        """Gets the description of this Item.  # noqa: E501

        The description of product / service, provided to Customer  # noqa: E501

        :return: The description of this Item.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Item.

        The description of product / service, provided to Customer  # noqa: E501

        :param description: The description of this Item.  # noqa: E501
        :type: str
        """
        if description is not None and len(description) > 200:
            raise ValueError(
                "Invalid value for `description`, length must be less than or equal to `200`"
            )  # noqa: E501
        if description is not None and len(description) < 1:
            raise ValueError(
                "Invalid value for `description`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._description = description

    @property
    def name(self):
        """Gets the name of this Item.  # noqa: E501

        The name of product / service, provided to Customer  # noqa: E501

        :return: The name of this Item.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Item.

        The name of product / service, provided to Customer  # noqa: E501

        :param name: The name of this Item.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501
        if name is not None and len(name) > 50:
            raise ValueError(
                "Invalid value for `name`, length must be less than or equal to `50`"
            )  # noqa: E501
        if name is not None and len(name) < 1:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._name = name

    @property
    def price(self):
        """Gets the price of this Item.  # noqa: E501

        Price of product / service with dot as a decimal separator, must be less than 1 million  # noqa: E501

        :return: The price of this Item.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this Item.

        Price of product / service with dot as a decimal separator, must be less than 1 million  # noqa: E501

        :param price: The price of this Item.  # noqa: E501
        :type: float
        """

        self._price = price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(Item, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Item):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.recurring_response_filing import (
    RecurringResponseFiling,
)  # noqa: F401,E501
from cardpay.model.updated_subscription_recurring_data import (
    UpdatedSubscriptionRecurringData,
)  # noqa: F401,E501


class UpdatedSubscriptionData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "change_status_claim_id": "str",
        "details": "str",
        "filing": "RecurringResponseFiling",
        "id": "str",
        "is_executed": "bool",
        "recurring_data": "UpdatedSubscriptionRecurringData",
        "remaining_amount": "float",
        "status": "str",
        "status_to": "str",
        "updated": "datetime",
    }

    attribute_map = {
        "change_status_claim_id": "change_status_claim_id",
        "details": "details",
        "filing": "filing",
        "id": "id",
        "is_executed": "is_executed",
        "recurring_data": "recurring_data",
        "remaining_amount": "remaining_amount",
        "status": "status",
        "status_to": "status_to",
        "updated": "updated",
    }

    def __init__(
        self,
        change_status_claim_id=None,
        details=None,
        filing=None,
        id=None,
        is_executed=None,
        recurring_data=None,
        remaining_amount=None,
        status=None,
        status_to=None,
        updated=None,
    ):  # noqa: E501
        """UpdatedSubscriptionData - a model defined in Swagger"""  # noqa: E501

        self._change_status_claim_id = None
        self._details = None
        self._filing = None
        self._id = None
        self._is_executed = None
        self._recurring_data = None
        self._remaining_amount = None
        self._status = None
        self._status_to = None
        self._updated = None
        self.discriminator = None

        if change_status_claim_id is not None:
            self.change_status_claim_id = change_status_claim_id
        if details is not None:
            self.details = details
        if filing is not None:
            self.filing = filing
        if id is not None:
            self.id = id
        if is_executed is not None:
            self.is_executed = is_executed
        if recurring_data is not None:
            self.recurring_data = recurring_data
        if remaining_amount is not None:
            self.remaining_amount = remaining_amount
        if status is not None:
            self.status = status
        if status_to is not None:
            self.status_to = status_to
        if updated is not None:
            self.updated = updated

    @property
    def change_status_claim_id(self):
        """Gets the change_status_claim_id of this UpdatedSubscriptionData.  # noqa: E501

        ID of claim; appears in case of request change was processed asynchronously and put in queue. Mandatory if request was put in queue.  # noqa: E501

        :return: The change_status_claim_id of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: str
        """
        return self._change_status_claim_id

    @change_status_claim_id.setter
    def change_status_claim_id(self, change_status_claim_id):
        """Sets the change_status_claim_id of this UpdatedSubscriptionData.

        ID of claim; appears in case of request change was processed asynchronously and put in queue. Mandatory if request was put in queue.  # noqa: E501

        :param change_status_claim_id: The change_status_claim_id of this UpdatedSubscriptionData.  # noqa: E501
        :type: str
        """

        self._change_status_claim_id = change_status_claim_id

    @property
    def details(self):
        """Gets the details of this UpdatedSubscriptionData.  # noqa: E501

        Operation details, errors, etc.  # noqa: E501

        :return: The details of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this UpdatedSubscriptionData.

        Operation details, errors, etc.  # noqa: E501

        :param details: The details of this UpdatedSubscriptionData.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def filing(self):
        """Gets the filing of this UpdatedSubscriptionData.  # noqa: E501

        Filing data  # noqa: E501

        :return: The filing of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: RecurringResponseFiling
        """
        return self._filing

    @filing.setter
    def filing(self, filing):
        """Sets the filing of this UpdatedSubscriptionData.

        Filing data  # noqa: E501

        :param filing: The filing of this UpdatedSubscriptionData.  # noqa: E501
        :type: RecurringResponseFiling
        """

        self._filing = filing

    @property
    def id(self):
        """Gets the id of this UpdatedSubscriptionData.  # noqa: E501

        ID of subscription  # noqa: E501

        :return: The id of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdatedSubscriptionData.

        ID of subscription  # noqa: E501

        :param id: The id of this UpdatedSubscriptionData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_executed(self):
        """Gets the is_executed of this UpdatedSubscriptionData.  # noqa: E501

        Status of operation  # noqa: E501

        :return: The is_executed of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: bool
        """
        return self._is_executed

    @is_executed.setter
    def is_executed(self, is_executed):
        """Sets the is_executed of this UpdatedSubscriptionData.

        Status of operation  # noqa: E501

        :param is_executed: The is_executed of this UpdatedSubscriptionData.  # noqa: E501
        :type: bool
        """

        self._is_executed = is_executed

    @property
    def recurring_data(self):
        """Gets the recurring_data of this UpdatedSubscriptionData.  # noqa: E501

        Recurring data  # noqa: E501

        :return: The recurring_data of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: UpdatedSubscriptionRecurringData
        """
        return self._recurring_data

    @recurring_data.setter
    def recurring_data(self, recurring_data):
        """Sets the recurring_data of this UpdatedSubscriptionData.

        Recurring data  # noqa: E501

        :param recurring_data: The recurring_data of this UpdatedSubscriptionData.  # noqa: E501
        :type: UpdatedSubscriptionRecurringData
        """

        self._recurring_data = recurring_data

    @property
    def remaining_amount(self):
        """Gets the remaining_amount of this UpdatedSubscriptionData.  # noqa: E501

        The amount remained to be paid after repayment operation. Mandatory for `REPAYMENT` operation only  # noqa: E501

        :return: The remaining_amount of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: float
        """
        return self._remaining_amount

    @remaining_amount.setter
    def remaining_amount(self, remaining_amount):
        """Sets the remaining_amount of this UpdatedSubscriptionData.

        The amount remained to be paid after repayment operation. Mandatory for `REPAYMENT` operation only  # noqa: E501

        :param remaining_amount: The remaining_amount of this UpdatedSubscriptionData.  # noqa: E501
        :type: float
        """

        self._remaining_amount = remaining_amount

    class Status(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"
        CANCELLED = "CANCELLED"
        PAST_DUE = "PAST_DUE"
        PENDING = "PENDING"
        COMPLETED = "COMPLETED"
        CARD_EXPIRED = "CARD_EXPIRED"
        ACTIVATION_FAILED = "ACTIVATION_FAILED"

    @property
    def status(self):
        """Gets the status of this UpdatedSubscriptionData.  # noqa: E501

        Resulted status of subscription  # noqa: E501

        :return: The status of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdatedSubscriptionData.

        Resulted status of subscription  # noqa: E501

        :param status: The status of this UpdatedSubscriptionData.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACTIVE",
            "INACTIVE",
            "CANCELLED",
            "PAST_DUE",
            "PENDING",
            "COMPLETED",
            "CARD_EXPIRED",
            "ACTIVATION_FAILED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    class StatusTo(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"
        CANCELLED = "CANCELLED"
        PAST_DUE = "PAST_DUE"
        PENDING = "PENDING"
        COMPLETED = "COMPLETED"
        CARD_EXPIRED = "CARD_EXPIRED"
        ACTIVATION_FAILED = "ACTIVATION_FAILED"

    @property
    def status_to(self):
        """Gets the status_to of this UpdatedSubscriptionData.  # noqa: E501

        Requested status of subscription. Mandatory for `CHANGE_STATUS` operation only.  # noqa: E501

        :return: The status_to of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: str
        """
        return self._status_to

    @status_to.setter
    def status_to(self, status_to):
        """Sets the status_to of this UpdatedSubscriptionData.

        Requested status of subscription. Mandatory for `CHANGE_STATUS` operation only.  # noqa: E501

        :param status_to: The status_to of this UpdatedSubscriptionData.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACTIVE",
            "INACTIVE",
            "CANCELLED",
            "PAST_DUE",
            "PENDING",
            "COMPLETED",
            "CARD_EXPIRED",
            "ACTIVATION_FAILED",
        ]  # noqa: E501
        if status_to not in allowed_values:
            raise ValueError(
                "Invalid value for `status_to` ({0}), must be one of {1}".format(  # noqa: E501
                    status_to, allowed_values
                )
            )

        self._status_to = status_to

    @property
    def updated(self):
        """Gets the updated of this UpdatedSubscriptionData.  # noqa: E501

        If request is successful then date and time returned in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z').  # noqa: E501

        :return: The updated of this UpdatedSubscriptionData.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this UpdatedSubscriptionData.

        If request is successful then date and time returned in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format (format - yyyy-MM-dd'T'HH:mm:ss'Z').  # noqa: E501

        :param updated: The updated of this UpdatedSubscriptionData.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(UpdatedSubscriptionData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatedSubscriptionData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentResponseCustomer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "email": "str",
        "full_name": "str",
        "id": "str",
        "ip": "str",
        "locale": "str",
        "phone": "str",
    }

    attribute_map = {
        "email": "email",
        "full_name": "full_name",
        "id": "id",
        "ip": "ip",
        "locale": "locale",
        "phone": "phone",
    }

    def __init__(
        self, email=None, full_name=None, id=None, ip=None, locale=None, phone=None
    ):  # noqa: E501
        """PaymentResponseCustomer - a model defined in Swagger"""  # noqa: E501

        self._email = None
        self._full_name = None
        self._id = None
        self._ip = None
        self._locale = None
        self._phone = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if full_name is not None:
            self.full_name = full_name
        if id is not None:
            self.id = id
        if ip is not None:
            self.ip = ip
        if locale is not None:
            self.locale = locale
        if phone is not None:
            self.phone = phone

    @property
    def email(self):
        """Gets the email of this PaymentResponseCustomer.  # noqa: E501

        Email address of the customer (mandatory by default for 'Latin America', 'NETELLER', 'DIRECTBANKINGNGA', 'AQRCODE', 'AIRTEL', 'MPESA', 'MTN', 'UGANDAMOBILE', 'VODAFONE', 'TIGO' payment methods only)). Can be defined as optional by CardPay manager.  # noqa: E501

        :return: The email of this PaymentResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PaymentResponseCustomer.

        Email address of the customer (mandatory by default for 'Latin America', 'NETELLER', 'DIRECTBANKINGNGA', 'AQRCODE', 'AIRTEL', 'MPESA', 'MTN', 'UGANDAMOBILE', 'VODAFONE', 'TIGO' payment methods only)). Can be defined as optional by CardPay manager.  # noqa: E501

        :param email: The email of this PaymentResponseCustomer.  # noqa: E501
        :type: str
        """
        if email is not None and len(email) > 256:
            raise ValueError(
                "Invalid value for `email`, length must be less than or equal to `256`"
            )  # noqa: E501
        if email is not None and len(email) < 1:
            raise ValueError(
                "Invalid value for `email`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._email = email

    @property
    def full_name(self):
        """Gets the full_name of this PaymentResponseCustomer.  # noqa: E501

        Customer's full name  # noqa: E501

        :return: The full_name of this PaymentResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this PaymentResponseCustomer.

        Customer's full name  # noqa: E501

        :param full_name: The full_name of this PaymentResponseCustomer.  # noqa: E501
        :type: str
        """
        if full_name is not None and len(full_name) > 256:
            raise ValueError(
                "Invalid value for `full_name`, length must be less than or equal to `256`"
            )  # noqa: E501
        if full_name is not None and len(full_name) < 1:
            raise ValueError(
                "Invalid value for `full_name`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._full_name = full_name

    @property
    def id(self):
        """Gets the id of this PaymentResponseCustomer.  # noqa: E501

        Customer's ID in the merchant's system  # noqa: E501

        :return: The id of this PaymentResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentResponseCustomer.

        Customer's ID in the merchant's system  # noqa: E501

        :param id: The id of this PaymentResponseCustomer.  # noqa: E501
        :type: str
        """
        if id is not None and len(id) > 256:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `256`"
            )  # noqa: E501
        if id is not None and len(id) < 0:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._id = id

    @property
    def ip(self):
        """Gets the ip of this PaymentResponseCustomer.  # noqa: E501

        IP address of Customer  # noqa: E501

        :return: The ip of this PaymentResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this PaymentResponseCustomer.

        IP address of Customer  # noqa: E501

        :param ip: The ip of this PaymentResponseCustomer.  # noqa: E501
        :type: str
        """
        if ip is not None and len(ip) > 15:
            raise ValueError(
                "Invalid value for `ip`, length must be less than or equal to `15`"
            )  # noqa: E501
        if ip is not None and len(ip) < 1:
            raise ValueError(
                "Invalid value for `ip`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._ip = ip

    @property
    def locale(self):
        """Gets the locale of this PaymentResponseCustomer.  # noqa: E501

        Preferred locale for the payment page ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) language code). The default locale will be applied if the selected locale is not supported. Supported locales are: `ru`, `en`, `zh`, `ja`  # noqa: E501

        :return: The locale of this PaymentResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this PaymentResponseCustomer.

        Preferred locale for the payment page ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) language code). The default locale will be applied if the selected locale is not supported. Supported locales are: `ru`, `en`, `zh`, `ja`  # noqa: E501

        :param locale: The locale of this PaymentResponseCustomer.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def phone(self):
        """Gets the phone of this PaymentResponseCustomer.  # noqa: E501

        Customer's phone number. Mandatory for DIRECTBANKINGNGA payment method. For other payment methods: optional by default, can be defined as mandatory by CardPay manager.  # noqa: E501

        :return: The phone of this PaymentResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this PaymentResponseCustomer.

        Customer's phone number. Mandatory for DIRECTBANKINGNGA payment method. For other payment methods: optional by default, can be defined as mandatory by CardPay manager.  # noqa: E501

        :param phone: The phone of this PaymentResponseCustomer.  # noqa: E501
        :type: str
        """
        if phone is not None and len(phone) > 12:
            raise ValueError(
                "Invalid value for `phone`, length must be less than or equal to `12`"
            )  # noqa: E501
        if phone is not None and len(phone) < 11:
            raise ValueError(
                "Invalid value for `phone`, length must be greater than or equal to `11`"
            )  # noqa: E501

        self._phone = phone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentResponseCustomer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentResponseCustomer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentRequestCard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "acct_type": "str",
        "expiration": "str",
        "holder": "str",
        "pan": "str",
        "security_code": "str",
    }

    attribute_map = {
        "acct_type": "acct_type",
        "expiration": "expiration",
        "holder": "holder",
        "pan": "pan",
        "security_code": "security_code",
    }

    def __init__(
        self, acct_type=None, expiration=None, holder=None, pan=None, security_code=None
    ):  # noqa: E501
        """PaymentRequestCard - a model defined in Swagger"""  # noqa: E501

        self._acct_type = None
        self._expiration = None
        self._holder = None
        self._pan = None
        self._security_code = None
        self.discriminator = None

        if acct_type is not None:
            self.acct_type = acct_type
        self.expiration = expiration
        self.holder = holder
        self.pan = pan
        self.security_code = security_code

    class AcctType(object):
        _01 = "01"
        _02 = "02"
        _03 = "03"

    @property
    def acct_type(self):
        """Gets the acct_type of this PaymentRequestCard.  # noqa: E501


        :return: The acct_type of this PaymentRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._acct_type

    @acct_type.setter
    def acct_type(self, acct_type):
        """Sets the acct_type of this PaymentRequestCard.


        :param acct_type: The acct_type of this PaymentRequestCard.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "02", "03"]  # noqa: E501
        if acct_type not in allowed_values:
            raise ValueError(
                "Invalid value for `acct_type` ({0}), must be one of {1}".format(  # noqa: E501
                    acct_type, allowed_values
                )
            )

        self._acct_type = acct_type

    @property
    def expiration(self):
        """Gets the expiration of this PaymentRequestCard.  # noqa: E501

        Customer's card expiration date. Format: `mm/yyyy`  # noqa: E501

        :return: The expiration of this PaymentRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this PaymentRequestCard.

        Customer's card expiration date. Format: `mm/yyyy`  # noqa: E501

        :param expiration: The expiration of this PaymentRequestCard.  # noqa: E501
        :type: str
        """
        if expiration is None:
            raise ValueError(
                "Invalid value for `expiration`, must not be `None`"
            )  # noqa: E501
        if expiration is not None and not re.search(
            r"([0-9]{2}\/[0-9]{4})", expiration
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `expiration`, must be a follow pattern or equal to `/([0-9]{2}\/[0-9]{4})/`"
            )  # noqa: E501

        self._expiration = expiration

    @property
    def holder(self):
        """Gets the holder of this PaymentRequestCard.  # noqa: E501

        Customer's cardholder name. Any valid cardholder name  # noqa: E501

        :return: The holder of this PaymentRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._holder

    @holder.setter
    def holder(self, holder):
        """Sets the holder of this PaymentRequestCard.

        Customer's cardholder name. Any valid cardholder name  # noqa: E501

        :param holder: The holder of this PaymentRequestCard.  # noqa: E501
        :type: str
        """
        if holder is None:
            raise ValueError(
                "Invalid value for `holder`, must not be `None`"
            )  # noqa: E501
        if holder is not None and len(holder) > 50:
            raise ValueError(
                "Invalid value for `holder`, length must be less than or equal to `50`"
            )  # noqa: E501
        if holder is not None and len(holder) < 1:
            raise ValueError(
                "Invalid value for `holder`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._holder = holder

    @property
    def pan(self):
        """Gets the pan of this PaymentRequestCard.  # noqa: E501

        Customer's card number (PAN). Any valid card number, may contain spaces  # noqa: E501

        :return: The pan of this PaymentRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._pan

    @pan.setter
    def pan(self, pan):
        """Sets the pan of this PaymentRequestCard.

        Customer's card number (PAN). Any valid card number, may contain spaces  # noqa: E501

        :param pan: The pan of this PaymentRequestCard.  # noqa: E501
        :type: str
        """
        if pan is None:
            raise ValueError(
                "Invalid value for `pan`, must not be `None`"
            )  # noqa: E501
        if pan is not None and len(pan) > 19:
            raise ValueError(
                "Invalid value for `pan`, length must be less than or equal to `19`"
            )  # noqa: E501
        if pan is not None and len(pan) < 13:
            raise ValueError(
                "Invalid value for `pan`, length must be greater than or equal to `13`"
            )  # noqa: E501

        self._pan = pan

    @property
    def security_code(self):
        """Gets the security_code of this PaymentRequestCard.  # noqa: E501

        Customer's CVV2 / CVC2 / CAV2  # noqa: E501

        :return: The security_code of this PaymentRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._security_code

    @security_code.setter
    def security_code(self, security_code):
        """Sets the security_code of this PaymentRequestCard.

        Customer's CVV2 / CVC2 / CAV2  # noqa: E501

        :param security_code: The security_code of this PaymentRequestCard.  # noqa: E501
        :type: str
        """
        if security_code is None:
            raise ValueError(
                "Invalid value for `security_code`, must not be `None`"
            )  # noqa: E501
        if security_code is not None and not re.search(
            r"[0-9]{3,4}", security_code
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `security_code`, must be a follow pattern or equal to `/[0-9]{3,4}/`"
            )  # noqa: E501

        self._security_code = security_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentRequestCard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestCard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
